@@ -1,13 +1,14 @@
 from processing import process
 from preprocessing import preprocess
 from systemcommands import setup
-from sys import argv as args
+from sys import argv
 from os import path
+from logging import warning
 
-def main():
-    del args[0]
+def main(args, cmd=False):
+    if cmd: del args[0]
     if not args:
-        print("You have to specify the file/s")
+        if cmd: print("You have to specify the file/s")
         return
     
     setup()
@@ -22,14 +23,11 @@ def main():
             with open(f"{filename}.html", "w") as file:
                 file.write("<!DOCTYPE html>\n" + html)
             
-            print(f"The file {arg} compiled.")
+            if cmd: print(f"The file {arg} compiled.")
                 
         except FileNotFoundError as e:
-            print(f"Hey! One of the files ({arg}) doesn't exist. Continuing with all of the other files...")
-        
-#         except ModuleNotFoundError as e:
-#             print("Hey! One of the modules in this file is not found. Sometimes it's happing due to an error and running again will solve the problem.")
-#             print("If running the compiling again didn't solve it, You may have missing files in your folder.")
+            if cmd: print(f"Hey! One of the files ({arg}) doesn't exist. Continuing with all of the other files...")
+            else: warning(f"One of the files ({arg}) is not found. ")
             
 if __name__ == "__main__":
-    main()
+    main(argv, True)
