@@ -5,6 +5,10 @@ from systemcommands.loop_ import loop_
 from systemcommands.safe_ import safe_
 from systemcommands.set_ import set_
 from systemcommands.compile_ import compile_
+from systemcommands.terminal_ import terminal_
+from systemcommands.tofile_ import tofile_
+from systemcommands.delfile_ import delfile_
+from systemcommands.readfile_ import readfile_
 
 def add_system_command(command, func):
     SYSTEM_COMMANDS[command] = func
@@ -20,4 +24,7 @@ def setup():
     add_system_command("@import", import_)
     add_system_command("@loop", loop_)
     add_system_command("@compile", compile_)
-    
\ No newline at end of file
+    add_system_command("@terminal", terminal_)
+    add_system_command("@tofile", tofile_)
+    add_system_command("@delfile", delfile_)
+    add_system_command("@readfile", readfile_)
\ No newline at end of file
